@@ -6,4 +6,9 @@ class Site(models.Model):
     slug = models.SlugField()
 
     def __unicode__(self):
-        return self.title
\ No newline at end of file
+        return self.title
+
+class SiteModelMixin:
+    @classmethod
+    def for_site(cls, site):
+        return cls.objects.filter(site=site)
